pub struct ControlEvent {
pub id: String,
pub value: ControlValue,
}Expand description
Emitted when the user interacts with an InlineControl.
Fields
id: StringThe id of the control that was interacted with.
value: ControlValueTrait Implementations
Sourceimpl Clone for ControlEvent
impl Clone for ControlEvent
Sourcefn clone(&self) -> ControlEvent
fn clone(&self) -> ControlEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ControlEvent
impl Debug for ControlEvent
Sourceimpl PartialEq for ControlEvent
impl PartialEq for ControlEvent
Sourcefn eq(&self, other: &ControlEvent) -> bool
fn eq(&self, other: &ControlEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ControlEvent